@@ -30,6 +30,8 @@ class PersonalLogFiles:
                 self.frames.append(read)
             except PermissionError:
                 self.permission.append(os.path.split(file)[-1].split("_")[0])
+            except Exception as e:
+                self.badlogs.append(f"Something odd here: {os.path.split(file)[-1].split('_')[0]}")
 
     def save(self):
         extracted_path = os.path.join(self.path, "Extracted")
