@@ -1,9 +1,11 @@
-from tkinter import filedialog, simpledialog, Listbox
+import traceback
 from tkinter import *
+from tkinter import messagebox
+
+from aihelper import Browse, Popup, OkButton
+
 from crplog import PersonalLogFiles
 from crplog import initial
-from aihelper import Browse, Popup, OkButton
-from tkinter import messagebox
 
 
 def looper():
@@ -25,6 +27,11 @@ def on_closing(parent):
         parent.destroy()
 
 
+def error(original, ins_text):
+    original.insert(0, ins_text)
+    return "\n".join(original)
+
+
 def close(file_path, root):
     try:
         file_path = file_path.get()
@@ -32,18 +39,21 @@ def close(file_path, root):
         data.extract_data()
         data.save()
         permission = data.permission
+        badlogs = data.badlogs
         if permission:
-            permission.insert(
-                0,
-                "The following user log files are open. The data will not reflect their logs",
-            )
-            unable_to_fetch = "\n".join(permission)
+            unable_to_fetch = error(permission,
+                                    "The following user log files are open. The data will not reflect their logs")
             Popup(text=unable_to_fetch, parent=root)
-        else:
-            Popup(text="All done", parent=root)
+        if badlogs:
+            bad_log_files = error(badlogs,
+                                  "The following users have bad log data. An attempt was made to repair it in the compiled file", )
+            Popup(text=bad_log_files, parent=root)
+        Popup(text="All done", parent=root)
     except Exception as e:
+        full_traceback = traceback.format_exc()
         Popup(
-            text=f"Something I failed to account for came up. Good luck {e}",
+            text=f"Something I failed to account for came up. The Following:  {e}"
+                 f"Full traceback: {full_traceback}",
             parent=root,
         )
 
